# Changelog

## 1.0.2 - August 14, 2014

- IE8 bugfix. Check for console.log raised an error.

## 1.0.1 - January 29, 2014

- Fix bower.json syntax error

## 1.0.0 - January 29, 2014

- List dev dependencies for bower
- Initial release
